
:orphan:

bcftools
========

Automatically generated index page for bcftools:

.. raw:: html

   <ul>

   </ul>
     <a href="bcftoolsannotate.html">
       <p style="margin-bottom: 5px"><b>BCFTools: Annotate</b> <span style="margin-left: 10px; color: darkgray">bcftoolsAnnotate</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="bcftoolsannotate.html" style="margin-bottom: 10px">
       v<b>1.9</b>
     </a></p>
     </a>
     <hr />
         
     <a href="bcftoolsconcat.html">
       <p style="margin-bottom: 5px"><b>BCFTools: Concat</b> <span style="margin-left: 10px; color: darkgray">bcftoolsConcat</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="bcftoolsconcat.html" style="margin-bottom: 10px">
       v<b>1.9</b>
     </a></p>
     </a>
     <hr />
         
     <a href="bcftoolsindex.html">
       <p style="margin-bottom: 5px"><b>BCFTools: Index</b> <span style="margin-left: 10px; color: darkgray">bcftoolsIndex</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="bcftoolsindex.html" style="margin-bottom: 10px">
       v<b>1.9</b>
     </a></p>
     </a>
     <hr />
         
     <a href="bcftoolsnorm.html">
       <p style="margin-bottom: 5px"><b>BCFTools: Normalize</b> <span style="margin-left: 10px; color: darkgray">bcftoolsNorm</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="bcftoolsnorm.html" style="margin-bottom: 10px">
       v<b>1.9</b>
     </a></p>
     </a>
     <hr />
         
     <a href="bcftoolssort.html">
       <p style="margin-bottom: 5px"><b>BCFTools: Sort</b> <span style="margin-left: 10px; color: darkgray">bcftoolssort</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(1 versions)</span><a class="version-button" href="bcftoolssort.html" style="margin-bottom: 10px">
       v<b>1.9</b>
     </a></p>
     </a>
     <hr />
         
     <a href="bcftoolsview.html">
       <p style="margin-bottom: 5px"><b>BCFTools: View</b> <span style="margin-left: 10px; color: darkgray">bcftoolsview</span></p>
       
       <p><span style="margin-right: 10px; color: darkgray">(2 versions)</span><a class="version-button" href="bcftoolsview.html" style="margin-bottom: 10px">
       v<b>1.9</b>
     </a></p>
     </a>
     <hr />
         

